summaryrefslogtreecommitdiffstats
path: root/src/render/backend
diff options
context:
space:
mode:
Diffstat (limited to 'src/render/backend')
-rw-r--r--src/render/backend/attachmentpack_p.h2
-rw-r--r--src/render/backend/cameralens.cpp6
-rw-r--r--src/render/backend/cameralens_p.h6
-rw-r--r--src/render/backend/entity.cpp38
-rw-r--r--src/render/backend/entity_p.h60
-rw-r--r--src/render/backend/handle_types_p.h52
-rw-r--r--src/render/backend/layer.cpp6
-rw-r--r--src/render/backend/layer_p.h6
-rw-r--r--src/render/backend/managers_p.h160
-rw-r--r--src/render/backend/nodefunctor_p.h8
-rw-r--r--src/render/backend/parameterpack.cpp6
-rw-r--r--src/render/backend/parameterpack_p.h8
-rw-r--r--src/render/backend/quniformvalue.cpp4
-rw-r--r--src/render/backend/quniformvalue_p.h18
-rw-r--r--src/render/backend/renderattachment.cpp8
-rw-r--r--src/render/backend/renderattachment_p.h10
-rw-r--r--src/render/backend/renderer.cpp18
-rw-r--r--src/render/backend/renderer_p.h24
-rw-r--r--src/render/backend/rendertarget.cpp8
-rw-r--r--src/render/backend/rendertarget_p.h14
-rw-r--r--src/render/backend/renderview.cpp2
-rw-r--r--src/render/backend/renderview_p.h10
-rw-r--r--src/render/backend/transform.cpp8
-rw-r--r--src/render/backend/transform_p.h6
24 files changed, 244 insertions, 244 deletions
diff --git a/src/render/backend/attachmentpack_p.h b/src/render/backend/attachmentpack_p.h
index f08c12f1c..cbf96cc99 100644
--- a/src/render/backend/attachmentpack_p.h
+++ b/src/render/backend/attachmentpack_p.h
@@ -62,7 +62,7 @@ struct Attachment
QString m_name;
int m_mipLevel;
int m_layer;
- Qt3D::QNodeId m_textureUuid;
+ Qt3DCore::QNodeId m_textureUuid;
QRenderAttachment::RenderAttachmentType m_type;
QRenderAttachment::CubeMapFace m_face;
};
diff --git a/src/render/backend/cameralens.cpp b/src/render/backend/cameralens.cpp
index faf4fee06..72a392277 100644
--- a/src/render/backend/cameralens.cpp
+++ b/src/render/backend/cameralens.cpp
@@ -46,7 +46,7 @@
QT_BEGIN_NAMESPACE
-using namespace Qt3D;
+using namespace Qt3DCore;
namespace Qt3DRender {
namespace Render {
@@ -67,7 +67,7 @@ void CameraLens::cleanup()
}
-void CameraLens::updateFromPeer(Qt3D::QNode *peer)
+void CameraLens::updateFromPeer(Qt3DCore::QNode *peer)
{
QCameraLens *lens = static_cast<QCameraLens *>(peer);
setProjection(lens->projectionMatrix());
@@ -79,7 +79,7 @@ void CameraLens::setProjection(const QMatrix4x4 &projection)
m_projection = projection;
}
-void CameraLens::sceneChangeEvent(const Qt3D::QSceneChangePtr &e)
+void CameraLens::sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e)
{
switch (e->type()) {
case NodeUpdated: {
diff --git a/src/render/backend/cameralens_p.h b/src/render/backend/cameralens_p.h
index 0fcea9826..b997db679 100644
--- a/src/render/backend/cameralens_p.h
+++ b/src/render/backend/cameralens_p.h
@@ -60,14 +60,14 @@ namespace Render {
class CameraManager;
-class CameraLens : public Qt3D::QBackendNode
+class CameraLens : public Qt3DCore::QBackendNode
{
public:
CameraLens();
~CameraLens();
void cleanup();
- void updateFromPeer(Qt3D::QNode *peer) Q_DECL_OVERRIDE;
+ void updateFromPeer(Qt3DCore::QNode *peer) Q_DECL_OVERRIDE;
void setClearColor();
QVector4D clearColor() const { return m_clearColor; }
@@ -77,7 +77,7 @@ public:
inline bool isEnabled() const { return m_enabled; }
- void sceneChangeEvent(const Qt3D::QSceneChangePtr &e) Q_DECL_OVERRIDE;
+ void sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e) Q_DECL_OVERRIDE;
private:
QVector4D m_clearColor;
diff --git a/src/render/backend/entity.cpp b/src/render/backend/entity.cpp
index 9aa0da946..e76eb2102 100644
--- a/src/render/backend/entity.cpp
+++ b/src/render/backend/entity.cpp
@@ -57,7 +57,7 @@
QT_BEGIN_NAMESPACE
-using namespace Qt3D;
+using namespace Qt3DCore;
namespace Qt3DRender {
namespace Render {
@@ -93,10 +93,10 @@ void Entity::cleanup()
qCDebug(Render::RenderNodes) << Q_FUNC_INFO;
// Clear components
- m_transformComponent = Qt3D::QNodeId();
- m_cameraComponent = Qt3D::QNodeId();
- m_materialComponent = Qt3D::QNodeId();
- m_geometryRendererComponent = Qt3D::QNodeId();
+ m_transformComponent = Qt3DCore::QNodeId();
+ m_cameraComponent = Qt3DCore::QNodeId();
+ m_materialComponent = Qt3DCore::QNodeId();
+ m_geometryRendererComponent = Qt3DCore::QNodeId();
m_layerComponents.clear();
m_shaderDataComponents.clear();
}
@@ -131,7 +131,7 @@ void Entity::setHandle(HEntity handle)
m_handle = handle;
}
-void Entity::updateFromPeer(Qt3D::QNode *peer)
+void Entity::updateFromPeer(Qt3DCore::QNode *peer)
{
QEntity *entity = static_cast<QEntity *>(peer);
const QNodeId parentEntityId = entity->parentEntityId();
@@ -157,7 +157,7 @@ void Entity::updateFromPeer(Qt3D::QNode *peer)
}
}
-void Entity::sceneChangeEvent(const Qt3D::QSceneChangePtr &e)
+void Entity::sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e)
{
QScenePropertyChangePtr propertyChange = qSharedPointerCast<QScenePropertyChange>(e);
switch (e->type()) {
@@ -237,12 +237,12 @@ const QMatrix4x4 *Entity::worldTransform() const
return m_renderer->worldMatrixManager()->data(m_worldTransform);
}
-void Entity::addComponent(Qt3D::QComponent *component)
+void Entity::addComponent(Qt3DCore::QComponent *component)
{
// The backend element is always created when this method is called
// If that's not the case something has gone wrong
- if (qobject_cast<Qt3D::QTransform*>(component) != Q_NULLPTR)
+ if (qobject_cast<Qt3DCore::QTransform*>(component) != Q_NULLPTR)
m_transformComponent = component->id();
else if (qobject_cast<QCameraLens *>(component) != Q_NULLPTR)
m_cameraComponent = component->id();
@@ -256,7 +256,7 @@ void Entity::addComponent(Qt3D::QComponent *component)
m_geometryRendererComponent = component->id();
}
-void Entity::removeComponent(const Qt3D::QNodeId &nodeId)
+void Entity::removeComponent(const Qt3DCore::QNodeId &nodeId)
{
if (m_transformComponent == nodeId)
m_transformComponent = QNodeId();
@@ -321,13 +321,13 @@ GeometryRenderer *Entity::renderComponent<GeometryRenderer>() const
}
template<>
-Qt3D::QNodeId Entity::componentUuid<Transform>() const { return m_transformComponent; }
+Qt3DCore::QNodeId Entity::componentUuid<Transform>() const { return m_transformComponent; }
template<>
-Qt3D::QNodeId Entity::componentUuid<CameraLens>() const { return m_cameraComponent; }
+Qt3DCore::QNodeId Entity::componentUuid<CameraLens>() const { return m_cameraComponent; }
template<>
-Qt3D::QNodeId Entity::componentUuid<Material>() const { return m_materialComponent; }
+Qt3DCore::QNodeId Entity::componentUuid<Material>() const { return m_materialComponent; }
template<>
QList<HLayer> Entity::componentsHandle<Layer>() const
@@ -348,7 +348,7 @@ QList<Layer *> Entity::renderComponents<Layer>() const
}
template<>
-QList<Qt3D::QNodeId> Entity::componentsUuid<Layer>() const { return m_layerComponents; }
+QList<Qt3DCore::QNodeId> Entity::componentsUuid<Layer>() const { return m_layerComponents; }
template<>
QList<HShaderData> Entity::componentsHandle<ShaderData>() const
@@ -369,10 +369,10 @@ QList<ShaderData *> Entity::renderComponents<ShaderData>() const
}
template<>
-QList<Qt3D::QNodeId> Entity::componentsUuid<ShaderData>() const { return m_shaderDataComponents; }
+QList<Qt3DCore::QNodeId> Entity::componentsUuid<ShaderData>() const { return m_shaderDataComponents; }
template<>
-Qt3D::QNodeId Entity::componentUuid<GeometryRenderer>() const { return m_geometryRendererComponent; }
+Qt3DCore::QNodeId Entity::componentUuid<GeometryRenderer>() const { return m_geometryRendererComponent; }
RenderEntityFunctor::RenderEntityFunctor(Renderer *renderer)
@@ -380,7 +380,7 @@ RenderEntityFunctor::RenderEntityFunctor(Renderer *renderer)
{
}
-Qt3D::QBackendNode *RenderEntityFunctor::create(Qt3D::QNode *frontend, const Qt3D::QBackendNodeFactory *factory) const
+Qt3DCore::QBackendNode *RenderEntityFunctor::create(Qt3DCore::QNode *frontend, const Qt3DCore::QBackendNodeFactory *factory) const
{
HEntity renderNodeHandle = m_renderer->renderNodesManager()->getOrAcquireHandle(frontend->id());
Entity *entity = m_renderer->renderNodesManager()->data(renderNodeHandle);
@@ -391,12 +391,12 @@ Qt3D::QBackendNode *RenderEntityFunctor::create(Qt3D::QNode *frontend, const Qt3
return entity;
}
-Qt3D::QBackendNode *RenderEntityFunctor::get(const Qt3D::QNodeId &id) const
+Qt3DCore::QBackendNode *RenderEntityFunctor::get(const Qt3DCore::QNodeId &id) const
{
return m_renderer->renderNodesManager()->lookupResource(id);
}
-void RenderEntityFunctor::destroy(const Qt3D::QNodeId &id) const
+void RenderEntityFunctor::destroy(const Qt3DCore::QNodeId &id) const
{
m_renderer->renderNodesManager()->releaseResource(id);
}
diff --git a/src/render/backend/entity_p.h b/src/render/backend/entity_p.h
index 1091d3751..947dccef1 100644
--- a/src/render/backend/entity_p.h
+++ b/src/render/backend/entity_p.h
@@ -60,7 +60,7 @@ QT_BEGIN_NAMESPACE
class QMatrix4x4;
-namespace Qt3D {
+namespace Qt3DCore {
class QNode;
class QEntity;
class QComponent;
@@ -75,7 +75,7 @@ namespace Render {
class Renderer;
-class Q_AUTOTEST_EXPORT Entity : public Qt3D::QBackendNode
+class Q_AUTOTEST_EXPORT Entity : public Qt3DCore::QBackendNode
{
public:
Entity();
@@ -84,8 +84,8 @@ public:
void setParentHandle(HEntity parentHandle);
void setRenderer(Renderer *renderer);
- void sceneChangeEvent(const Qt3D::QSceneChangePtr &e) Q_DECL_OVERRIDE;
- void updateFromPeer(Qt3D::QNode *peer) Q_DECL_OVERRIDE;
+ void sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e) Q_DECL_OVERRIDE;
+ void updateFromPeer(Qt3DCore::QNode *peer) Q_DECL_OVERRIDE;
void dump() const;
@@ -104,19 +104,19 @@ public:
Sphere *localBoundingVolume() { return m_localBoundingVolume; }
Sphere *worldBoundingVolume() { return m_worldBoundingVolume; }
- void addComponent(Qt3D::QComponent *component);
- void removeComponent(const Qt3D::QNodeId &nodeId);
+ void addComponent(Qt3DCore::QComponent *component);
+ void removeComponent(const Qt3DCore::QNodeId &nodeId);
template<class Backend, uint INDEXBITS>
- Qt3D::QHandle<Backend, INDEXBITS> componentHandle() const
+ Qt3DCore::QHandle<Backend, INDEXBITS> componentHandle() const
{
- return Qt3D::QHandle<Backend, INDEXBITS>();
+ return Qt3DCore::QHandle<Backend, INDEXBITS>();
}
template<class Backend, uint INDEXBITS>
- QList<Qt3D::QHandle<Backend, INDEXBITS> > componentsHandle() const
+ QList<Qt3DCore::QHandle<Backend, INDEXBITS> > componentsHandle() const
{
- return QList<Qt3D::QHandle<Backend, INDEXBITS> >();
+ return QList<Qt3DCore::QHandle<Backend, INDEXBITS> >();
}
template<class Backend>
@@ -132,15 +132,15 @@ public:
}
template<class Backend>
- Qt3D::QNodeId componentUuid() const
+ Qt3DCore::QNodeId componentUuid() const
{
- return Qt3D::QNodeId();
+ return Qt3DCore::QNodeId();
}
template<class Backend>
- QList<Qt3D::QNodeId> componentsUuid() const
+ QList<Qt3DCore::QNodeId> componentsUuid() const
{
- return QList<Qt3D::QNodeId>();
+ return QList<Qt3DCore::QNodeId>();
}
private:
@@ -166,12 +166,12 @@ private:
Sphere *m_worldBoundingVolume;
// Handles to Components
- Qt3D::QNodeId m_transformComponent;
- Qt3D::QNodeId m_materialComponent;
- Qt3D::QNodeId m_cameraComponent;
- QList<Qt3D::QNodeId> m_layerComponents;
- QList<Qt3D::QNodeId> m_shaderDataComponents;
- Qt3D::QNodeId m_geometryRendererComponent;
+ Qt3DCore::QNodeId m_transformComponent;
+ Qt3DCore::QNodeId m_materialComponent;
+ Qt3DCore::QNodeId m_cameraComponent;
+ QList<Qt3DCore::QNodeId> m_layerComponents;
+ QList<Qt3DCore::QNodeId> m_shaderDataComponents;
+ Qt3DCore::QNodeId m_geometryRendererComponent;
QString m_objectName;
};
@@ -201,13 +201,13 @@ template<>
Q_AUTOTEST_EXPORT GeometryRenderer *Entity::renderComponent<GeometryRenderer>() const;
template<>
-Q_AUTOTEST_EXPORT Qt3D::QNodeId Entity::componentUuid<Transform>() const;
+Q_AUTOTEST_EXPORT Qt3DCore::QNodeId Entity::componentUuid<Transform>() const;
template<>
-Q_AUTOTEST_EXPORT Qt3D::QNodeId Entity::componentUuid<CameraLens>() const;
+Q_AUTOTEST_EXPORT Qt3DCore::QNodeId Entity::componentUuid<CameraLens>() const;
template<>
-Q_AUTOTEST_EXPORT Qt3D::QNodeId Entity::componentUuid<Material>() const;
+Q_AUTOTEST_EXPORT Qt3DCore::QNodeId Entity::componentUuid<Material>() const;
template<>
QList<HLayer> Entity::componentsHandle<Layer>() const;
@@ -216,7 +216,7 @@ template<>
QList<Layer *> Entity::renderComponents<Layer>() const;
template<>
-Q_AUTOTEST_EXPORT QList<Qt3D::QNodeId> Entity::componentsUuid<Layer>() const;
+Q_AUTOTEST_EXPORT QList<Qt3DCore::QNodeId> Entity::componentsUuid<Layer>() const;
template<>
QList<HShaderData> Entity::componentsHandle<ShaderData>() const;
@@ -225,18 +225,18 @@ template<>
QList<ShaderData *> Entity::renderComponents<ShaderData>() const;
template<>
-Q_AUTOTEST_EXPORT QList<Qt3D::QNodeId> Entity::componentsUuid<ShaderData>() const;
+Q_AUTOTEST_EXPORT QList<Qt3DCore::QNodeId> Entity::componentsUuid<ShaderData>() const;
template<>
-Q_AUTOTEST_EXPORT Qt3D::QNodeId Entity::componentUuid<GeometryRenderer>() const;
+Q_AUTOTEST_EXPORT Qt3DCore::QNodeId Entity::componentUuid<GeometryRenderer>() const;
-class RenderEntityFunctor : public Qt3D::QBackendNodeFunctor
+class RenderEntityFunctor : public Qt3DCore::QBackendNodeFunctor
{
public:
explicit RenderEntityFunctor(Renderer *renderer);
- Qt3D::QBackendNode *create(Qt3D::QNode *frontend, const Qt3D::QBackendNodeFactory *factory) const Q_DECL_OVERRIDE;
- Qt3D::QBackendNode *get(const Qt3D::QNodeId &id) const Q_DECL_OVERRIDE;
- void destroy(const Qt3D::QNodeId &id) const Q_DECL_OVERRIDE;
+ Qt3DCore::QBackendNode *create(Qt3DCore::QNode *frontend, const Qt3DCore::QBackendNodeFactory *factory) const Q_DECL_OVERRIDE;
+ Qt3DCore::QBackendNode *get(const Qt3DCore::QNodeId &id) const Q_DECL_OVERRIDE;
+ void destroy(const Qt3DCore::QNodeId &id) const Q_DECL_OVERRIDE;
private:
Renderer *m_renderer;
diff --git a/src/render/backend/handle_types_p.h b/src/render/backend/handle_types_p.h
index 4761ba4f7..27f8dafc4 100644
--- a/src/render/backend/handle_types_p.h
+++ b/src/render/backend/handle_types_p.h
@@ -85,32 +85,32 @@ class Attribute;
class Geometry;
class GeometryRenderer;
-typedef Qt3D::QHandle<RenderAttachment, 16> HAttachment;
-typedef Qt3D::QHandle<CameraLens, 8> HCamera;
-typedef Qt3D::QHandle<Annotation, 16> HCriterion;
-typedef Qt3D::QHandle<Effect, 16> HEffect;
-typedef Qt3D::QHandle<Entity, 16> HEntity;
-typedef Qt3D::QHandle<FrameGraphNode *, 8> HFrameGraphNode;
-typedef Qt3D::QHandle<Layer, 16> HLayer;
-typedef Qt3D::QHandle<Material, 16> HMaterial;
-typedef Qt3D::QHandle<QMatrix4x4, 16> HMatrix;
-typedef Qt3D::QHandle<Shader, 16> HShader;
-typedef Qt3D::QHandle<QOpenGLVertexArrayObject*, 16> HVao;
-typedef Qt3D::QHandle<Shader, 16> HShader;
-typedef Qt3D::QHandle<SortCriterion, 8> HSortCriterion;
-typedef Qt3D::QHandle<Technique, 16> HTechnique;
-typedef Qt3D::QHandle<Texture, 16> HTexture;
-typedef Qt3D::QHandle<Transform, 16> HTransform;
-typedef Qt3D::QHandle<RenderTarget, 8> HTarget;
-typedef Qt3D::QHandle<RenderPass, 16> HRenderPass;
-typedef Qt3D::QHandle<TexImageData, 16> HTextureData;
-typedef Qt3D::QHandle<Parameter, 16> HParameter;
-typedef Qt3D::QHandle<ShaderData, 16> HShaderData;
-typedef Qt3D::QHandle<TextureImage, 16> HTextureImage;
-typedef Qt3D::QHandle<Buffer, 16> HBuffer;
-typedef Qt3D::QHandle<Attribute, 16> HAttribute;
-typedef Qt3D::QHandle<Geometry, 16> HGeometry;
-typedef Qt3D::QHandle<GeometryRenderer, 16> HGeometryRenderer;
+typedef Qt3DCore::QHandle<RenderAttachment, 16> HAttachment;
+typedef Qt3DCore::QHandle<CameraLens, 8> HCamera;
+typedef Qt3DCore::QHandle<Annotation, 16> HCriterion;
+typedef Qt3DCore::QHandle<Effect, 16> HEffect;
+typedef Qt3DCore::QHandle<Entity, 16> HEntity;
+typedef Qt3DCore::QHandle<FrameGraphNode *, 8> HFrameGraphNode;
+typedef Qt3DCore::QHandle<Layer, 16> HLayer;
+typedef Qt3DCore::QHandle<Material, 16> HMaterial;
+typedef Qt3DCore::QHandle<QMatrix4x4, 16> HMatrix;
+typedef Qt3DCore::QHandle<Shader, 16> HShader;
+typedef Qt3DCore::QHandle<QOpenGLVertexArrayObject*, 16> HVao;
+typedef Qt3DCore::QHandle<Shader, 16> HShader;
+typedef Qt3DCore::QHandle<SortCriterion, 8> HSortCriterion;
+typedef Qt3DCore::QHandle<Technique, 16> HTechnique;
+typedef Qt3DCore::QHandle<Texture, 16> HTexture;
+typedef Qt3DCore::QHandle<Transform, 16> HTransform;
+typedef Qt3DCore::QHandle<RenderTarget, 8> HTarget;
+typedef Qt3DCore::QHandle<RenderPass, 16> HRenderPass;
+typedef Qt3DCore::QHandle<TexImageData, 16> HTextureData;
+typedef Qt3DCore::QHandle<Parameter, 16> HParameter;
+typedef Qt3DCore::QHandle<ShaderData, 16> HShaderData;
+typedef Qt3DCore::QHandle<TextureImage, 16> HTextureImage;
+typedef Qt3DCore::QHandle<Buffer, 16> HBuffer;
+typedef Qt3DCore::QHandle<Attribute, 16> HAttribute;
+typedef Qt3DCore::QHandle<Geometry, 16> HGeometry;
+typedef Qt3DCore::QHandle<GeometryRenderer, 16> HGeometryRenderer;
} // namespace Render
diff --git a/src/render/backend/layer.cpp b/src/render/backend/layer.cpp
index fdd180d26..332882802 100644
--- a/src/render/backend/layer.cpp
+++ b/src/render/backend/layer.cpp
@@ -41,7 +41,7 @@
QT_BEGIN_NAMESPACE
-using namespace Qt3D;
+using namespace Qt3DCore;
namespace Qt3DRender {
namespace Render {
@@ -60,7 +60,7 @@ void Layer::cleanup()
{
}
-void Layer::updateFromPeer(Qt3D::QNode *peer)
+void Layer::updateFromPeer(Qt3DCore::QNode *peer)
{
QLayer *layer = static_cast<QLayer *>(peer);
m_layers = layer->names();
@@ -72,7 +72,7 @@ QStringList Layer::layers() const
return m_layers;
}
-void Layer::sceneChangeEvent(const Qt3D::QSceneChangePtr &e)
+void Layer::sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e)
{
QScenePropertyChangePtr propertyChange = qSharedPointerCast<QScenePropertyChange>(e);
if (e->type() == NodeUpdated && propertyChange->propertyName() == QByteArrayLiteral("names"))
diff --git a/src/render/backend/layer_p.h b/src/render/backend/layer_p.h
index 05ac73711..d75e7164c 100644
--- a/src/render/backend/layer_p.h
+++ b/src/render/backend/layer_p.h
@@ -62,17 +62,17 @@ namespace Render {
class LayerManager;
-class Layer : public Qt3D::QBackendNode
+class Layer : public Qt3DCore::QBackendNode
{
public:
Layer();
~Layer();
void cleanup();
- void updateFromPeer(Qt3D::QNode *peer) Q_DECL_OVERRIDE;
+ void updateFromPeer(Qt3DCore::QNode *peer) Q_DECL_OVERRIDE;
QStringList layers() const;
- void sceneChangeEvent(const Qt3D::QSceneChangePtr &e) Q_DECL_OVERRIDE;
+ void sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e) Q_DECL_OVERRIDE;
inline bool isEnabled() const { return m_enabled; }
private:
diff --git a/src/render/backend/managers_p.h b/src/render/backend/managers_p.h
index e59228e4b..1c4e9d86e 100644
--- a/src/render/backend/managers_p.h
+++ b/src/render/backend/managers_p.h
@@ -77,150 +77,150 @@ namespace Qt3DRender {
namespace Render {
-class AttachmentManager : public Qt3D::QResourceManager<
+class AttachmentManager : public Qt3DCore::QResourceManager<
RenderAttachment,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
AttachmentManager() {}
};
-class CameraManager : public Qt3D::QResourceManager<
+class CameraManager : public Qt3DCore::QResourceManager<
CameraLens,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
8,
- Qt3D::ArrayAllocatingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy>
{
public:
CameraManager() {}
};
-class CriterionManager : public Qt3D::QResourceManager<
+class CriterionManager : public Qt3DCore::QResourceManager<
Annotation,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
CriterionManager() {}
};
-class EffectManager : public Qt3D::QResourceManager<
+class EffectManager : public Qt3DCore::QResourceManager<
Effect,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
EffectManager() {}
};
-class EntityManager : public Qt3D::QResourceManager<Entity, Qt3D::QNodeId, 16>
+class EntityManager : public Qt3DCore::QResourceManager<Entity, Qt3DCore::QNodeId, 16>
{
public:
EntityManager() {}
};
-class FrameGraphManager : public Qt3D::QResourceManager<
+class FrameGraphManager : public Qt3DCore::QResourceManager<
FrameGraphNode *,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
8,
- Qt3D::ArrayAllocatingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy>
{
public:
FrameGraphManager() {}
};
-class LayerManager : public Qt3D::QResourceManager<
+class LayerManager : public Qt3DCore::QResourceManager<
Layer,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
LayerManager() {}
};
-class MaterialManager : public Qt3D::QResourceManager<
+class MaterialManager : public Qt3DCore::QResourceManager<
Material,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
MaterialManager() {}
};
-class MatrixManager : public Qt3D::QResourceManager<QMatrix4x4, Qt3D::QNodeId, 16>
+class MatrixManager : public Qt3DCore::QResourceManager<QMatrix4x4, Qt3DCore::QNodeId, 16>
{
public:
MatrixManager() {}
};
-class ShaderManager : public Qt3D::QResourceManager<
+class ShaderManager : public Qt3DCore::QResourceManager<
Shader,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
ShaderManager() {}
};
-class SortCriterionManager : public Qt3D::QResourceManager<
+class SortCriterionManager : public Qt3DCore::QResourceManager<
SortCriterion,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
8,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
SortCriterionManager() {}
};
-class TechniqueManager : public Qt3D::QResourceManager<
+class TechniqueManager : public Qt3DCore::QResourceManager<
Technique,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
TechniqueManager() {}
};
-class TextureManager : public Qt3D::QResourceManager<
+class TextureManager : public Qt3DCore::QResourceManager<
Texture,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
TextureManager() {}
};
-class TransformManager : public Qt3D::QResourceManager<
+class TransformManager : public Qt3DCore::QResourceManager<
Transform,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
TransformManager() {}
};
-class VAOManager : public Qt3D::QResourceManager<
+class VAOManager : public Qt3DCore::QResourceManager<
QOpenGLVertexArrayObject *,
QPair<HGeometry, HShader>,
16>
@@ -229,84 +229,84 @@ public:
VAOManager() {}
};
-class RenderTargetManager : public Qt3D::QResourceManager<
+class RenderTargetManager : public Qt3DCore::QResourceManager<
RenderTarget,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
8,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
RenderTargetManager() {}
};
-class RenderPassManager : public Qt3D::QResourceManager<
+class RenderPassManager : public Qt3DCore::QResourceManager<
RenderPass,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
RenderPassManager() {}
};
-class ParameterManager : public Qt3D::QResourceManager<
+class ParameterManager : public Qt3DCore::QResourceManager<
Parameter,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
ParameterManager() {}
};
-class ShaderDataManager : public Qt3D::QResourceManager<
+class ShaderDataManager : public Qt3DCore::QResourceManager<
ShaderData,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
public:
ShaderDataManager() {}
};
-class UBOManager : public Qt3D::QResourceManager<
+class UBOManager : public Qt3DCore::QResourceManager<
UniformBuffer,
ShaderDataShaderUboKey,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
};
-class TextureImageManager : public Qt3D::QResourceManager<
+class TextureImageManager : public Qt3DCore::QResourceManager<
TextureImage,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
};
-class AttributeManager : public Qt3D::QResourceManager<
+class AttributeManager : public Qt3DCore::QResourceManager<
Attribute,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
};
-class GeometryManager : public Qt3D::QResourceManager<
+class GeometryManager : public Qt3DCore::QResourceManager<
Geometry,
- Qt3D::QNodeId,
+ Qt3DCore::QNodeId,
16,
- Qt3D::ArrayAllocatingPolicy,
- Qt3D::ObjectLevelLockingPolicy>
+ Qt3DCore::ArrayAllocatingPolicy,
+ Qt3DCore::ObjectLevelLockingPolicy>
{
};
diff --git a/src/render/backend/nodefunctor_p.h b/src/render/backend/nodefunctor_p.h
index 0067cba81..6a2a902b8 100644
--- a/src/render/backend/nodefunctor_p.h
+++ b/src/render/backend/nodefunctor_p.h
@@ -58,7 +58,7 @@ namespace Qt3DRender {
namespace Render {
template<class Backend, class Manager>
-class NodeFunctor : public Qt3D::QBackendNodeFunctor
+class NodeFunctor : public Qt3DCore::QBackendNodeFunctor
{
public:
explicit NodeFunctor(Manager *manager)
@@ -66,7 +66,7 @@ public:
{
}
- Qt3D::QBackendNode *create(Qt3D::QNode *frontend, const Qt3D::QBackendNodeFactory *factory) const Q_DECL_FINAL
+ Qt3DCore::QBackendNode *create(Qt3DCore::QNode *frontend, const Qt3DCore::QBackendNodeFactory *factory) const Q_DECL_FINAL
{
Backend *backend = m_manager->getOrCreateResource(frontend->id());
backend->setFactory(factory);
@@ -74,12 +74,12 @@ public:
return backend;
}
- Qt3D::QBackendNode *get(const Qt3D::QNodeId &id) const Q_DECL_FINAL
+ Qt3DCore::QBackendNode *get(const Qt3DCore::QNodeId &id) const Q_DECL_FINAL
{
return m_manager->lookupResource(id);
}
- void destroy(const Qt3D::QNodeId &id) const Q_DECL_FINAL
+ void destroy(const Qt3DCore::QNodeId &id) const Q_DECL_FINAL
{
m_manager->releaseResource(id);
}
diff --git a/src/render/backend/parameterpack.cpp b/src/render/backend/parameterpack.cpp
index 3d6553363..17b1c3eef 100644
--- a/src/render/backend/parameterpack.cpp
+++ b/src/render/backend/parameterpack.cpp
@@ -55,19 +55,19 @@ void ParameterPack::clear()
m_peers.clear();
}
-void ParameterPack::appendParameter(const Qt3D::QNodeId &parameterId)
+void ParameterPack::appendParameter(const Qt3DCore::QNodeId &parameterId)
{
if (!m_peers.contains(parameterId)) {
m_peers.append(parameterId);
}
}
-void ParameterPack::removeParameter(const Qt3D::QNodeId &parameterId)
+void ParameterPack::removeParameter(const Qt3DCore::QNodeId &parameterId)
{
m_peers.removeOne(parameterId);
}
-QList<Qt3D::QNodeId> ParameterPack::parameters() const
+QList<Qt3DCore::QNodeId> ParameterPack::parameters() const
{
return m_peers;
}
diff --git a/src/render/backend/parameterpack_p.h b/src/render/backend/parameterpack_p.h
index 74413548e..274797f0d 100644
--- a/src/render/backend/parameterpack_p.h
+++ b/src/render/backend/parameterpack_p.h
@@ -63,12 +63,12 @@ public:
ParameterPack();
~ParameterPack();
void clear();
- void appendParameter(const Qt3D::QNodeId &parameterId);
- void removeParameter(const Qt3D::QNodeId &parameterId);
- QList<Qt3D::QNodeId> parameters() const;
+ void appendParameter(const Qt3DCore::QNodeId &parameterId);
+ void removeParameter(const Qt3DCore::QNodeId &parameterId);
+ QList<Qt3DCore::QNodeId> parameters() const;
private:
- QList<Qt3D::QNodeId> m_peers;
+ QList<Qt3DCore::QNodeId> m_peers;
};
} // namespace Render
diff --git a/src/render/backend/quniformvalue.cpp b/src/render/backend/quniformvalue.cpp
index 140035d80..df25fb466 100644
--- a/src/render/backend/quniformvalue.cpp
+++ b/src/render/backend/quniformvalue.cpp
@@ -56,7 +56,7 @@ QUniformValue::QUniformValue()
{
}
-QUniformValue *QUniformValue::fromVariant(const QVariant &v, Qt3D::QFrameAllocator *allocator)
+QUniformValue *QUniformValue::fromVariant(const QVariant &v, Qt3DCore::QFrameAllocator *allocator)
{
QUniformValue *u = allocator->allocate<QUniformValue>();
u->m_var = v;
@@ -88,7 +88,7 @@ void QUniformPack::setUniform(const QString &glslName, const QUniformValue *val)
m_uniforms.insert(glslName, val);
}
-void QUniformPack::setTexture(const QString &glslName, const Qt3D::QNodeId &texId)
+void QUniformPack::setTexture(const QString &glslName, const Qt3DCore::QNodeId &texId)
{
for (int t=0; t<m_textures.size(); ++t) {
if (m_textures[t].glslName != glslName) {
diff --git a/src/render/backend/quniformvalue_p.h b/src/render/backend/quniformvalue_p.h
index 9a57b9027..51bb2fc29 100644
--- a/src/render/backend/quniformvalue_p.h
+++ b/src/render/backend/quniformvalue_p.h
@@ -61,7 +61,7 @@ QT_BEGIN_NAMESPACE
class QOpenGLShaderProgram;
-namespace Qt3D {
+namespace Qt3DCore {
class QFrameAllocator;
}
@@ -79,7 +79,7 @@ public:
QUniformValue();
virtual ~QUniformValue() {}
- static QUniformValue *fromVariant(const QVariant &v, Qt3D::QFrameAllocator *allocator);
+ static QUniformValue *fromVariant(const QVariant &v, Qt3DCore::QFrameAllocator *allocator);
virtual bool operator ==(const QUniformValue &other);
bool operator !=(const QUniformValue &other);
@@ -109,12 +109,12 @@ public :
return true;
}
- void setTextureId(const Qt3D::QNodeId &id)
+ void setTextureId(const Qt3DCore::QNodeId &id)
{
m_textureId = id;
}
- Qt3D::QNodeId textureId() const { return m_textureId; }
+ Qt3DCore::QNodeId textureId() const { return m_textureId; }
bool operator ==(const QUniformValue &other) Q_DECL_OVERRIDE
{
@@ -131,13 +131,13 @@ public :
void apply(GraphicsContext *ctx, const ShaderUniform &description) const Q_DECL_OVERRIDE;
private:
- Qt3D::QNodeId m_textureId;
+ Qt3DCore::QNodeId m_textureId;
int m_textureUnit;
};
struct BlockToUBO {
int m_blockIndex;
- Qt3D::QNodeId m_shaderDataID;
+ Qt3DCore::QNodeId m_shaderDataID;
bool m_needsUpdate;
QHash<QString, QVariant> m_updatedProperties;
};
@@ -148,7 +148,7 @@ public:
~QUniformPack();
void setUniform(const QString &glslName, const QUniformValue *val);
- void setTexture(const QString &glslName, const Qt3D::QNodeId &id);
+ void setTexture(const QString &glslName, const Qt3DCore::QNodeId &id);
void setUniformBuffer(const BlockToUBO &blockToUBO);
inline const QHash<QString, const QUniformValue* > &uniforms() const { return m_uniforms; }
@@ -157,13 +157,13 @@ public:
struct NamedTexture
{
NamedTexture() {}
- NamedTexture(const QString &nm, const Qt3D::QNodeId &t)
+ NamedTexture(const QString &nm, const Qt3DCore::QNodeId &t)
: glslName(nm)
, texId(t)
{ }
QString glslName;
- Qt3D::QNodeId texId;
+ Qt3DCore::QNodeId texId;
};
inline QVector<NamedTexture> textures() const { return m_textures; }
diff --git a/src/render/backend/renderattachment.cpp b/src/render/backend/renderattachment.cpp
index a62ae76a5..92436a217 100644
--- a/src/render/backend/renderattachment.cpp
+++ b/src/render/backend/renderattachment.cpp
@@ -41,7 +41,7 @@
QT_BEGIN_NAMESPACE
-using namespace Qt3D;
+using namespace Qt3DCore;
namespace Qt3DRender {
namespace Render {
@@ -51,7 +51,7 @@ RenderAttachment::RenderAttachment()
{
}
-void RenderAttachment::updateFromPeer(Qt3D::QNode *peer)
+void RenderAttachment::updateFromPeer(Qt3DCore::QNode *peer)
{
QRenderAttachment *attachment = static_cast<QRenderAttachment *>(peer);
@@ -64,7 +64,7 @@ void RenderAttachment::updateFromPeer(Qt3D::QNode *peer)
m_attachmentData.m_textureUuid = attachment->texture()->id();
}
-Qt3D::QNodeId RenderAttachment::textureUuid() const
+Qt3DCore::QNodeId RenderAttachment::textureUuid() const
{
return m_attachmentData.m_textureUuid;
}
@@ -94,7 +94,7 @@ QRenderAttachment::RenderAttachmentType RenderAttachment::type() const
return m_attachmentData.m_type;
}
-void RenderAttachment::sceneChangeEvent(const Qt3D::QSceneChangePtr &e)
+void RenderAttachment::sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e)
{
QScenePropertyChangePtr propertyChange = qSharedPointerCast<QScenePropertyChange>(e);
if (e->type() == NodeUpdated) {
diff --git a/src/render/backend/renderattachment_p.h b/src/render/backend/renderattachment_p.h
index e20ded8ef..d2c4487c0 100644
--- a/src/render/backend/renderattachment_p.h
+++ b/src/render/backend/renderattachment_p.h
@@ -63,24 +63,24 @@ namespace Render {
class AttachmentManager;
-class RenderAttachment : public Qt3D::QBackendNode
+class RenderAttachment : public Qt3DCore::QBackendNode
{
public:
RenderAttachment();
- void updateFromPeer(Qt3D::QNode *peer) Q_DECL_OVERRIDE;
+ void updateFromPeer(Qt3DCore::QNode *peer) Q_DECL_OVERRIDE;
- Qt3D::QNodeId textureUuid() const;
+ Qt3DCore::QNodeId textureUuid() const;
int mipLevel() const;
int layer() const;
QString name() const;
QRenderAttachment::CubeMapFace face() const;
QRenderAttachment::RenderAttachmentType type() const;
- void sceneChangeEvent(const Qt3D::QSceneChangePtr &e) Q_DECL_OVERRIDE;
+ void sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e) Q_DECL_OVERRIDE;
Attachment attachment() const;
private:
- Qt3D::QNodeId m_attachmentUuid;
+ Qt3DCore::QNodeId m_attachmentUuid;
Attachment m_attachmentData;
};
diff --git a/src/render/backend/renderer_p.h b/src/render/backend/renderer_p.h
index a1eb09ce6..f272de2ed 100644
--- a/src/render/backend/renderer_p.h
+++ b/src/render/backend/renderer_p.h
@@ -74,7 +74,7 @@ QT_BEGIN_NAMESPACE
class QSurface;
class QOpenGLDebugLogger;
-namespace Qt3D {
+namespace Qt3DCore {
class QEntity;
class QFrameAllocator;
}
@@ -148,11 +148,11 @@ public:
void createAllocators();
void destroyAllocators();
- Qt3D::QFrameAllocator *currentFrameAllocator();
+ Qt3DCore::QFrameAllocator *currentFrameAllocator();
- QThreadStorage<Qt3D::QFrameAllocator *> *tlsAllocators();
+ QThreadStorage<Qt3DCore::QFrameAllocator *> *tlsAllocators();
- void setFrameGraphRoot(const Qt3D::QNodeId &fgRoot);
+ void setFrameGraphRoot(const Qt3DCore::QNodeId &fgRoot);
Render::FrameGraphNode *frameGraphRoot() const;
void setSceneGraphRoot(Entity *sgRoot);
@@ -161,13 +161,13 @@ public:
void render();
void doRender();
- QVector<Qt3D::QAspectJobPtr> createRenderBinJobs();
- QVector<Qt3D::QAspectJobPtr> createRenderBufferJobs();
- QVector<Qt3D::QAspectJobPtr> createGeometryRendererJobs();
- Qt3D::QAspectJobPtr createRenderViewJob(FrameGraphNode *node, int submitOrderIndex);
+ QVector<Qt3DCore::QAspectJobPtr> createRenderBinJobs();
+ QVector<Qt3DCore::QAspectJobPtr> createRenderBufferJobs();
+ QVector<Qt3DCore::QAspectJobPtr> createGeometryRendererJobs();
+ Qt3DCore::QAspectJobPtr createRenderViewJob(FrameGraphNode *node, int submitOrderIndex);
void executeCommands(const QVector<RenderCommand *> &commands);
Attribute *updateBuffersAndAttributes(Geometry *geometry, RenderCommand *command, GLsizei &count, bool forceUpdate);
- void addAllocator(Qt3D::QFrameAllocator *allocator);
+ void addAllocator(Qt3DCore::QFrameAllocator *allocator);
inline CameraManager *cameraManager() const { return m_cameraManager; }
inline EntityManager *renderNodesManager() const { return m_renderNodesManager; }
@@ -225,7 +225,7 @@ private:
QRenderAspect *m_rendererAspect;
// Frame graph root
- Qt3D::QNodeId m_frameGraphRootUuid;
+ Qt3DCore::QNodeId m_frameGraphRootUuid;
Entity *m_renderSceneRoot;
@@ -293,13 +293,13 @@ private:
static void createThreadLocalAllocator(void *renderer);
static void destroyThreadLocalAllocator(void *renderer);
- QThreadStorage<Qt3D::QFrameAllocator *> m_tlsAllocators;
+ QThreadStorage<Qt3DCore::QFrameAllocator *> m_tlsAllocators;
QAtomicInt m_running;
QScopedPointer<QOpenGLDebugLogger> m_debugLogger;
QList<AbstractSceneParser *> m_sceneParsers;
- QVector<Qt3D::QFrameAllocator *> m_allocators;
+ QVector<Qt3DCore::QFrameAllocator *> m_allocators;
QVector<Attribute *> m_dirtyAttributes;
QVector<Geometry *> m_dirtyGeometry;
diff --git a/src/render/backend/rendertarget.cpp b/src/render/backend/rendertarget.cpp
index e55284377..dc528349c 100644
--- a/src/render/backend/rendertarget.cpp
+++ b/src/render/backend/rendertarget.cpp
@@ -42,7 +42,7 @@
QT_BEGIN_NAMESPACE
-using namespace Qt3D;
+using namespace Qt3DCore;
namespace Qt3DRender {
namespace Render {
@@ -52,7 +52,7 @@ RenderTarget::RenderTarget()
{
}
-void RenderTarget::updateFromPeer(Qt3D::QNode *peer)
+void RenderTarget::updateFromPeer(Qt3DCore::QNode *peer)
{
QRenderTarget *target = static_cast<QRenderTarget *>(peer);
m_renderAttachments.clear();
@@ -75,12 +75,12 @@ void RenderTarget::removeRenderAttachment(const QNodeId &attachmentId)
m_renderAttachments.removeOne(attachmentId);
}
-QList<Qt3D::QNodeId> RenderTarget::renderAttachments() const
+QList<Qt3DCore::QNodeId> RenderTarget::renderAttachments() const
{
return m_renderAttachments;
}
-void RenderTarget::sceneChangeEvent(const Qt3D::QSceneChangePtr &e)
+void RenderTarget::sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e)
{
QScenePropertyChangePtr propertyChange = qSharedPointerCast<QScenePropertyChange>(e);
if (e->type() == NodeAdded && propertyChange->propertyName() == QByteArrayLiteral("attachment"))
diff --git a/src/render/backend/rendertarget_p.h b/src/render/backend/rendertarget_p.h
index 4692a014e..e369ba320 100644
--- a/src/render/backend/rendertarget_p.h
+++ b/src/render/backend/rendertarget_p.h
@@ -63,23 +63,23 @@ namespace Render {
class RenderTargetManager;
-class RenderTarget : public Qt3D::QBackendNode
+class RenderTarget : public Qt3DCore::QBackendNode
{
public:
RenderTarget();
- void updateFromPeer(Qt3D::QNode *peer) Q_DECL_OVERRIDE;
+ void updateFromPeer(Qt3DCore::QNode *peer) Q_DECL_OVERRIDE;
void cleanup();
- void appendRenderAttachment(const Qt3D::QNodeId &attachmentId);
- void removeRenderAttachment(const Qt3D::QNodeId &attachmentId);
+ void appendRenderAttachment(const Qt3DCore::QNodeId &attachmentId);
+ void removeRenderAttachment(const Qt3DCore::QNodeId &attachmentId);
- QList<Qt3D::QNodeId> renderAttachments() const;
+ QList<Qt3DCore::QNodeId> renderAttachments() const;
- void sceneChangeEvent(const Qt3D::QSceneChangePtr &e) Q_DECL_OVERRIDE;
+ void sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e) Q_DECL_OVERRIDE;
private:
- QList<Qt3D::QNodeId> m_renderAttachments;
+ QList<Qt3DCore::QNodeId> m_renderAttachments;
};
} // namespace Render
diff --git a/src/render/backend/renderview.cpp b/src/render/backend/renderview.cpp
index c730b7ce2..4e5a1d890 100644
--- a/src/render/backend/renderview.cpp
+++ b/src/render/backend/renderview.cpp
@@ -94,7 +94,7 @@ bool isEntityInLayers(const Entity *entity, const QStringList &layers)
return false;
}
-void destroyUniformValue(const QUniformValue *value, Qt3D::QFrameAllocator *allocator)
+void destroyUniformValue(const QUniformValue *value, Qt3DCore::QFrameAllocator *allocator)
{
QUniformValue *v = const_cast<QUniformValue *>(value);
if (v->isTexture())
diff --git a/src/render/backend/renderview_p.h b/src/render/backend/renderview_p.h
index ef7cc77ed..6cf7a308c 100644
--- a/src/render/backend/renderview_p.h
+++ b/src/render/backend/renderview_p.h
@@ -104,7 +104,7 @@ public:
inline void setSurfaceSize(const QSize &size) { m_surfaceSize = size; }
inline Renderer *renderer() const { return m_renderer; }
- inline void setAllocator(Qt3D::QFrameAllocator *allocator)
+ inline void setAllocator(Qt3DCore::QFrameAllocator *allocator)
{
m_allocator = allocator;
m_data = m_allocator->allocate<InnerData>();
@@ -116,7 +116,7 @@ public:
// help cache performance during iteration
m_data->m_viewMatrix = m_allocator->allocate<QMatrix4x4>();
}
- inline Qt3D::QFrameAllocator *allocator() const { return m_allocator; }
+ inline Qt3DCore::QFrameAllocator *allocator() const { return m_allocator; }
inline void setRenderCamera(CameraLens *renderCamera) { m_data->m_renderCamera = renderCamera; }
inline CameraLens *renderCamera() const { return m_data->m_renderCamera; }
@@ -196,7 +196,7 @@ public:
void setRenderTargetHandle(HTarget renderTargetHandle) { m_renderTarget = renderTargetHandle; }
HTarget renderTargetHandle() const { return m_renderTarget; }
- void addSortCriteria(const QList<Qt3D::QNodeId> &sortMethodUid) { m_data->m_sortingCriteria.append(sortMethodUid); }
+ void addSortCriteria(const QList<Qt3DCore::QNodeId> &sortMethodUid) { m_data->m_sortingCriteria.append(sortMethodUid); }
// Helps making the size of RenderView smaller
// Contains all the data needed for the actual building of the RenderView
@@ -214,7 +214,7 @@ public:
const RenderPassFilter *m_passFilter;
QMatrix4x4 *m_viewMatrix;
QStringList m_layers;
- QList<Qt3D::QNodeId> m_sortingCriteria;
+ QList<Qt3DCore::QNodeId> m_sortingCriteria;
QVector3D m_eyePos;
UniformBlockValueBuilder m_uniformBlockBuilder;
};
@@ -224,7 +224,7 @@ private:
Renderer *m_renderer;
QSize m_surfaceSize;
- Qt3D::QFrameAllocator *m_allocator;
+ Qt3DCore::QFrameAllocator *m_allocator;
InnerData *m_data;
diff --git a/src/render/backend/transform.cpp b/src/render/backend/transform.cpp
index 91d9ee60e..cb633ace4 100644
--- a/src/render/backend/transform.cpp
+++ b/src/render/backend/transform.cpp
@@ -43,7 +43,7 @@
QT_BEGIN_NAMESPACE
-using namespace Qt3D;
+using namespace Qt3DCore;
namespace Qt3DRender {
namespace Render {
@@ -53,9 +53,9 @@ Transform::Transform()
{
}
-void Transform::updateFromPeer(Qt3D::QNode *peer)
+void Transform::updateFromPeer(Qt3DCore::QNode *peer)
{
- Qt3D::QTransform *transform = static_cast<Qt3D::QTransform *>(peer);
+ Qt3DCore::QTransform *transform = static_cast<Qt3DCore::QTransform *>(peer);
m_transformMatrix = transform->matrix();
m_enabled = transform->isEnabled();
@@ -66,7 +66,7 @@ QMatrix4x4 Transform::transformMatrix() const
return m_transformMatrix;
}
-void Transform::sceneChangeEvent(const Qt3D::QSceneChangePtr &e)
+void Transform::sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e)
{
if (e->type() == NodeUpdated) {
const QScenePropertyChangePtr &propertyChange = qSharedPointerCast<QScenePropertyChange>(e);
diff --git a/src/render/backend/transform_p.h b/src/render/backend/transform_p.h
index 195274e51..49d876424 100644
--- a/src/render/backend/transform_p.h
+++ b/src/render/backend/transform_p.h
@@ -60,14 +60,14 @@ namespace Render {
class Renderer;
class TransformManager;
-class Transform : public Qt3D::QBackendNode
+class Transform : public Qt3DCore::QBackendNode
{
public:
Transform();
- void updateFromPeer(Qt3D::QNode *peer) Q_DECL_OVERRIDE;
+ void updateFromPeer(Qt3DCore::QNode *peer) Q_DECL_OVERRIDE;
QMatrix4x4 transformMatrix() const;
- void sceneChangeEvent(const Qt3D::QSceneChangePtr &e) Q_DECL_OVERRIDE;
+ void sceneChangeEvent(const Qt3DCore::QSceneChangePtr &e) Q_DECL_OVERRIDE;
inline bool isEnabled() const { return m_enabled; }
private:
diff --git a/src/render/backend/renderer.cpp b/src/render/backend/renderer.cpp
index 5d42e7c6a..a68ee1cc4 100644
--- a/src/render/backend/renderer.cpp
+++ b/src/render/backend/renderer.cpp
@@ -97,7 +97,7 @@
QT_BEGIN_NAMESPACE
-using namespace Qt3D;
+using namespace Qt3DCore;
namespace Qt3DRender {
namespace Render {
@@ -326,7 +326,7 @@ void Renderer::createThreadLocalAllocator(void *renderer)
/*!
* Returns the a FrameAllocator for the caller thread.
*/
-Qt3D::QFrameAllocator *Renderer::currentFrameAllocator()
+Qt3DCore::QFrameAllocator *Renderer::currentFrameAllocator()
{
// return the QFrameAllocator for the current thread
// It is never cleared as each renderview when it is destroyed
@@ -429,7 +429,7 @@ void Renderer::shutdown()
}
}
-void Renderer::setFrameGraphRoot(const Qt3D::QNodeId &frameGraphRootUuid)
+void Renderer::setFrameGraphRoot(const Qt3DCore::QNodeId &frameGraphRootUuid)
{
m_frameGraphRootUuid = frameGraphRootUuid;
qCDebug(Backend) << Q_FUNC_INFO << m_frameGraphRootUuid;
@@ -550,7 +550,7 @@ void Renderer::render()
// Matrice update, bounding volumes computation ...
// Should be jobs
// namespace Qt3D has 2 distincts node trees
// One scene description
// One framegraph description
@@ -758,7 +758,7 @@ bool Renderer::submitRenderViews()
// Waits to be told to create jobs for the next frame
// Called by QRenderAspect jobsToExecute context of QAspectThread
-QVector<Qt3D::QAspectJobPtr> Renderer::createRenderBinJobs()
+QVector<Qt3DCore::QAspectJobPtr> Renderer::createRenderBinJobs()
{
// Traverse the current framegraph. For each leaf node create a
// RenderView and set its configuration then create a job to
@@ -781,7 +781,7 @@ QVector<Qt3D::QAspectJobPtr> Renderer::createRenderBinJobs()
// Returns a vector of jobs to be performed for dirty buffers
// 1 dirty buffer == 1 job, all job can be performed in parallel
-QVector<Qt3D::QAspectJobPtr> Renderer::createRenderBufferJobs()
+QVector<Qt3DCore::QAspectJobPtr> Renderer::createRenderBufferJobs()
{
const QVector<QNodeId> dirtyBuffers = m_bufferManager->dirtyBuffers();
QVector<QAspectJobPtr> dirtyBuffersJobs;
@@ -799,7 +799,7 @@ QVector<Qt3D::QAspectJobPtr> Renderer::createRenderBufferJobs()
return dirtyBuffersJobs;
}
-QVector<Qt3D::QAspectJobPtr> Renderer::createGeometryRendererJobs()
+QVector<Qt3DCore::QAspectJobPtr> Renderer::createGeometryRendererJobs()
{
const QVector<QNodeId> dirtyGeometryRenderers = m_geometryRendererManager->dirtyGeometryRenderers();
QVector<QAspectJobPtr> dirtyGeometryRendererJobs;
@@ -817,7 +817,7 @@ QVector<Qt3D::QAspectJobPtr> Renderer::createGeometryRendererJobs()
}
// Called during while traversing the FrameGraph for each leaf node context of QAspectThread
-Qt3D::QAspectJobPtr Renderer::createRenderViewJob(FrameGraphNode *node, int submitOrderIndex)
+Qt3DCore::QAspectJobPtr Renderer::createRenderViewJob(FrameGraphNode *node, int submitOrderIndex)
{
RenderViewJobPtr job(new RenderViewJob);
job->setRenderer(this);
@@ -1053,7 +1053,7 @@ Attribute *Renderer::updateBuffersAndAttributes(Geometry *geometry, RenderComman
return indexAttribute;
}
-void Renderer::addAllocator(Qt3D::QFrameAllocator *allocator)
+void Renderer::addAllocator(Qt3DCore::QFrameAllocator *allocator)
{
QMutexLocker lock(&m_mutex);
m_allocators.append(allocator);
@@ -550,7 +550,7 @@ void Renderer::render()
// Matrice update, bounding volumes computation ...
// Should be jobs
- // namespace Qt3D has 2 distincts node trees
+ // namespace Qt3DCore has 2 distincts node trees
// One scene description
// One framegraph description